/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2007-2008 - INRIA - Allan CORNET
 *
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

/*--------------------------------------------------------------------------*/
#ifndef __TERMINATHISTORYMANAGER_H__
#define __TERMINATHISTORYMANAGER_H__

#include "dynlib_history_manager.h"
#include "BOOL.h" /* BOOL */

HISTORY_MANAGER_IMPEXP BOOL TerminateHistoryManager(void);

#endif /* __TERMINATHISTORYMANAGER_H__ */
/*--------------------------------------------------------------------------*/
